==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/ToolActionIconButtonInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ToolActionInfo } from "./ToolActionInfo";
import { markType } from "./type";
/**
 * @hidden
 */
var ToolActionIconButtonInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionIconButtonInfo, _super);
    function ToolActionIconButtonInfo() {
        var _this = _super.call(this) || this;
        _this._tooltipDelay = 0;
        _this._isMenuOpenOnStart = false;
        _this.tooltipDelay = 500;
        return _this;
    }
    ToolActionIconButtonInfo.prototype.get_b = function () {
        return 3;
    };
    Object.defineProperty(ToolActionIconButtonInfo.prototype, "tooltipDelay", {
        get: function () {
            return this._tooltipDelay;
        },
        set: function (a) {
            this._tooltipDelay = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolActionIconButtonInfo.prototype, "isMenuOpenOnStart", {
        get: function () {
            return this._isMenuOpenOnStart;
        },
        set: function (a) {
            this._isMenuOpenOnStart = a;
        },
        enumerable: false,
        configurable: true
    });
    ToolActionIconButtonInfo.$t = markType(ToolActionIconButtonInfo, 'ToolActionIconButtonInfo', ToolActionInfo.$);
    return ToolActionIconButtonInfo;
}(ToolActionInfo));
export { ToolActionIconButtonInfo };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/ToolActionIconButtonInfo.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ToolActionInfo } from "./ToolActionInfo";
import { markType } from "./type";
/**
 * @hidden
 */
var ToolActionIconButtonInfo = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionIconButtonInfo, _super);
    function ToolActionIconButtonInfo() {
        var _this = _super.call(this) || this;
        _this._tooltipDelay = 0;
        _this._isMenuOpenOnStart = false;
        _this.tooltipDelay = -1;
        return _this;
    }
    ToolActionIconButtonInfo.prototype.get_b = function () {
        return 3;
    };
    Object.defineProperty(ToolActionIconButtonInfo.prototype, "tooltipDelay", {
        get: function () {
            return this._tooltipDelay;
        },
        set: function (a) {
            this._tooltipDelay = a;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(ToolActionIconButtonInfo.prototype, "isMenuOpenOnStart", {
        get: function () {
            return this._isMenuOpenOnStart;
        },
        set: function (a) {
            this._isMenuOpenOnStart = a;
        },
        enumerable: false,
        configurable: true
    });
    ToolActionIconButtonInfo.$t = markType(ToolActionIconButtonInfo, 'ToolActionIconButtonInfo', ToolActionInfo.$);
    return ToolActionIconButtonInfo;
}(ToolActionInfo));
export { ToolActionIconButtonInfo };
